@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from distutils.version import LooseVersion
+
 import django
 from django.conf import settings
 
@@ -20,6 +21,8 @@ DJANGO_1_5 = (LooseVersion(django.get_version()) < LooseVersion('1.6') and
 
 def get_setting(key):
     local_settings = {
+        'DISABLE': getattr(settings, "HTML5_APPCACHE_DISABLE", False),
+        'ADD_WILDCARD': getattr(settings, "HTML5_APPCACHE_ADD_WILDCARD", True),
         'CACHE_KEY': getattr(settings, "HTML5_APPCACHE_CACHE_KEY", "html5_appcache"),
         'CACHE_DURATION': getattr(settings, "HTML5_APPCACHE_CACHE_DURATION", 86400),
         'USE_SITEMAP': getattr(settings, "HTML5_APPCACHE_USE_SITEMAP", True),
